==> aroundme_0_3_3.tar: aroundme_0_3_3/www/aroundme_0_3_3/language/1/am_default/g_apply.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common_g.lang.php');

/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_group_rules'] = 						"group rules";
$lang['hdr_node_rules'] = 						"node rules";
$lang['hdr_join'] = 							"joining this group";


//SUBMIT BUTTONS
$lang['sub_join'] = 							"join";


//BODY TEXT
$lang['txt_join_notes'] = 						"I agree to the rules";
$lang['txt_joined'] = 							"joined";
$lang['txt_reg_group_member'] = 				"You are already a member of this group.";
$lang['txt_reg_group_pending'] = 				"Your group application is pending. The group administrator will Instant message you with the results of your application.";
$lang['txt_reg_group_pending_set'] = 			"Thank you for applying for this group. The group administrator will contact you shortly.";
$lang['txt_reg_group_open'] = 					"This group is an open group. When you press the button below you will automatically become a member of this group.";
$lang['txt_reg_group_reg'] = 					"This group is a registered group. This means that you can apply to join it by pressing the button below.<p>When you do this you group administration receives a request to join from you. They will then approve or reject your application and send you an Instant message.";
$lang['txt_reg_group_welcome'] = 				"Welcome to this group. Press the button below to come on in.";
$lang['href_group_welcome'] = 					"enter this group";

?>

==> aroundme-0_4_0.tar: aroundme_0_4_0/www/aroundme_0_4_0/language/1/am_default/g_apply.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'g_common.lang.php');

/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_group_rules'] = 						"group rules";
$lang['hdr_node_rules'] = 						"node rules";
$lang['hdr_join'] = 							"joining this group";


//SUBMIT BUTTONS
$lang['sub_join'] = 							"join";


//BODY TEXT
$lang['txt_join_notes'] = 						"I agree to the rules";
//$lang['txt_joined'] = 							"joined";
$lang['txt_group_pending'] = 					"Your group application is pending. The group administrator will Instant message you with the results of your application.";
$lang['txt_group_automatic'] = 					"Welcome to this group. Press the button below to come on in.";
$lang['txt_group_approved'] = 					"Welcome to this group. Press the button below to join. The group administrator will contact you if your application is approved";
$lang['txt_group_unavailable'] = 				"Sorry, this group is unavailable at this time.";
$lang['txt_profile_select_txt'] = 				"select the profile you wish to use in this group";
//$lang['href_group_welcome'] = 					"enter this group";

?>
